@@ -242,13 +242,13 @@ def DownloadData(Dir, Var, Startdate, Enddate, latlim, lonlim, TimeStep, Period,
                         
                         if TimeStep == "daily":
  
-                            if data_type in "min":
+                            if "min" in data_type:
                                 data_min = np.nanmin(data_end, 0)                            
                             
-                            if data_type in "max":
+                            if "max" in data_type:
                                 data_max = np.nanmax(data_end, 0)                            
                             
-                            if data_type in "mean":
+                            if "mean" in data_type:
                             
                                 if types == "state":
                                     data_end = np.nanmean(data_end, 0)
